macro_rules! impl_id_type {
($name:ident in $container:ident::$sub_container:ident -> $type:ty) => { ... };
}Expand description
Provides the implementation which allows the data of an IR to be accessed using an ID type generated using the id_type! macro.
Arguments
-
$name- the identifier of the id type -
$container- the identifier of the IR -
$sub_container- the field of the ir which contains the Arena this ID indexes -
$type- The type of the values that are indexed by this id
Examples
id_type!(NetId(u8));
impl_id_type!(NetId in Ast::nets -> AttributeNode<Net>);