pub struct Ident {
pub name: Symbol,
pub span: Span,
}Fields
name: Symbolspan: SpanImplementations
Sourceimpl Ident
impl Ident
Sourcepub const fn new(name: Symbol, span: Span) -> Self
pub const fn new(name: Symbol, span: Span) -> Self
Constructs a new identifier from a symbol and a span.
pub const fn empty() -> Self
pub const fn spanned_empty(span: Span) -> Self
Sourcepub fn from_str_and_span(string: &str, span: Span) -> Self
pub fn from_str_and_span(string: &str, span: Span) -> Self
Maps a string and a span to an identifier.
pub fn without_first_quote(self) -> Self