pub struct Symbol(/* private fields */);Expand description
An interned string.
Internally, a Symbol is implemented as an index, and all operations
(including hashing, equality, and ordering) operate on that index.
Implementations
Sourceimpl Symbol
impl Symbol
Sourcepub fn with<F: FnOnce(&str) -> R, R>(self, f: F) -> R
pub fn with<F: FnOnce(&str) -> R, R>(self, f: F) -> R
Access the symbol’s chars. This is a slowish operation because it requires locking the symbol interner.
Sourcepub fn as_str(self) -> SymbolStr
pub fn as_str(self) -> SymbolStr
Convert to a SymbolStr. This is a slowish operation because it
requires locking the symbol interner.
pub const fn as_u32(self) -> u32